@@ -1,7 +1,7 @@
 # ControlBreak.pm - Compare values during iteration to detect changes
 
 # Done:
-# - switch from using say join to using printf in the Synopsis example
+# - change to use v5.26 to align with Object::Pad 0.66 requirements and avoid test failures
 
 # To Do:
 # - provide an accumulate method that counts and sums an arbitrary number of named variables
@@ -118,7 +118,7 @@ place of B<test()> and B<continue()>.
 ########################################################################
 use strict;
 use warnings;
-use v5.18;
+use v5.26;      # minimum perl necessary for Object::Pad 0.66
 
 use Object::Pad 0.66 qw( :experimental(init_expr) );
 
@@ -128,7 +128,7 @@ class   ControlBreak;
 # althouth Object::Pad allows a version argument on the class statement
 # we can't use it because we want Dist::Zilla to set it from the dist.ini
 # version -- and that requires it to be an 'our' statement.
-our $VERSION = 'v0.22.243';
+our $VERSION = 'v0.22.244';
 
 use Carp            qw(croak);
 
